/***************************************************************************
 *   Copyright (C) 2010 by Helge Kortendieck  alan@kasmithee.de            *
 *   ldoss.cpp  -  set delay time and define program to launch             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#include "ldoss.h"

Ldoss::Ldoss( QMainWindow* parent )
        : QMainWindow( parent )
{
	bSetChg = false;
	bQuit = false;
	uis.setupUi( &wSetDlg );
//	setCentralWidget( &wSetDlg );
	toolBar = addToolBar( tr( "Show toolbar" ) );
	setRead();
	actionsCreate();
	menusCreate();
	toolBarCreate();
	QTimer::singleShot(500, this, SLOT( init() ) );		// init after a short delay
}

Ldoss::~Ldoss()
{
}


void Ldoss::init()
{
	wSetDlg.show();
}

void Ldoss::setRead()
{
	QSettings settings( "ldoss", "ldoss" );

	settings.beginGroup( "main" );
		wSetDlg.move( settings.value( "pos", QPoint(0, 0) ).toPoint() );			// settings dialog position and size
		wSetDlg.resize( settings.value( "size", QSize(400, 400) ).toSize() );
		uis.tE_Progs->setPlainText( settings.value( "progs", "" ).toString() );		// programs to launch, text edit content
		uis.spB_Delay->setValue( settings.value( "delay", "500" ).toInt() );		// delay to begin launch in milli seconds
	settings.endGroup();

	connect( uis.spB_Delay, SIGNAL( valueChanged( int ) ), this, SLOT( settingsChanged() ) );
	connect( uis.tE_Progs, SIGNAL( textChanged() ), this, SLOT( settingsChanged() ) );
//	connect( uis.pB_Cancel, SIGNAL( clicked() ), this, SLOT( dlgClose() ) );
//	connect( uis.pB_Save, SIGNAL( clicked() ), this, SLOT( dlgSave() ) );

//	bD = false;
}


void Ldoss::setWrite()
{
	QSettings settings( "ldoss", "ldoss" );

	settings.beginGroup( "main" );
		settings.setValue( "progs", uis.tE_Progs->toPlainText() );
		settings.setValue( "delay", uis.spB_Delay->value() );
	settings.endGroup();

	settings.sync();
}

void Ldoss::setWritePos()
{
	QSettings settings("ldoss", "ldoss");

	settings.beginGroup( "main" );
		settings.setValue( "pos", wSetDlg.pos() );
		settings.setValue( "size", wSetDlg.size() );
	settings.endGroup();

	settings.sync();
}

void Ldoss::actionsCreate()
{
	exitAct = new QAction(QIcon( "/usr/share/ldoss/quit.svg" ), tr( "&Quit" ), this);
	exitAct->setShortcut( tr( "Ctrl+Q" ) );
	exitAct->setStatusTip( tr( "Quit the application" ) );
	connect(exitAct, SIGNAL(triggered()), this, SLOT(dlgClosePrep()));

	helpAct = new QAction(QIcon( "/usr/share/ldoss/help.svg" ), tr( "&Help" ), this);
	helpAct->setShortcut( tr( "Ctrl+H" ) );
	helpAct->setStatusTip( tr( "Show the application's online help" ) );
	connect(helpAct, SIGNAL(triggered()), this, SLOT(ahwHelp()));

	aboutAct = new QAction(QIcon( "/usr/share/ldoss/about.svg" ), tr( "&About ldoss" ), this);
	aboutAct->setShortcut( tr( "Ctrl+A" ) );
	aboutAct->setStatusTip( tr( "Show the application's about information" ) );
	connect(aboutAct, SIGNAL(triggered()), this, SLOT(ahwAbout()));

	saveAct = new QAction(QIcon( "/usr/share/ldoss/save.svg" ), tr( "&Save" ), this);
	saveAct->setShortcut( tr( "Ctrl+S" ) );
	saveAct->setStatusTip( tr( "Save settings" ) );
	connect(saveAct, SIGNAL(triggered()), this, SLOT(dlgSave()));
	
	noSaveAct = new QAction(QIcon( "/usr/share/ldoss/nothingtosave.svg" ), tr( "&Nothing to save" ), this);
	noSaveAct->setShortcut( tr( "Ctrl+S" ) );
	noSaveAct->setStatusTip( tr( "Nothing to save" ) );
	connect(noSaveAct, SIGNAL(triggered()), this, SLOT(dlgSave()));
}

void Ldoss::menusCreate()
{
	wSetDlg.menuBar()->clear();
	fileMenu = wSetDlg.menuBar()->addMenu( tr( "&File" ) );
	if( bSetChg == true ) {
		fileMenu->addAction(saveAct);
	} else {
		fileMenu->addAction(noSaveAct);
	}
	fileMenu->addAction(exitAct);
	wSetDlg.menuBar()->addSeparator();
	helpMenu = wSetDlg.menuBar()->addMenu( tr( "&Help" ) );
	helpMenu->addAction(helpAct);
	helpMenu->addAction(aboutAct);
}

void Ldoss::toolBarCreate()
{
	uis.toolBar->clear();
	if( bSetChg == true ) {
		uis.toolBar->addAction(saveAct);
	} else {
		uis.toolBar->addAction(noSaveAct);
	}
	uis.toolBar->addAction(exitAct);
}


void Ldoss::settingsChanged()				// changes to the settings were made
{
	bSetChg = true;
	menusCreate();
	toolBarCreate();
//	uis.pB_Save->setEnabled( true );
}

void Ldoss::dlgSave()						// save settings
{
	if( bSetChg == true ) {
		setWrite();
		bSetChg = false;
		menusCreate();
		toolBarCreate();
		if( bQuit == true ) {
			dlgClosePrep();
		}
	}
}

void Ldoss::dlgClosePrep()					// prepare closing settings dialog
{
	setWritePos();
	if( bSetChg == true ) {						// pending changes
		QMessageBox msgBox;
		msgBox.setWindowTitle( tr( "Save changes ?" ) );
		msgBox.setIcon( QMessageBox::Question );
		msgBox.setText( tr( "There are pending changes, save before exiting ?" ) );
		msgBox.addButton( tr( "Yes, &Save" ), QMessageBox::AcceptRole );
		msgBox.addButton( tr( "No, &Exit now" ), QMessageBox::RejectRole );
		msgBox.move( 200, 200 );
		if( msgBox.exec() == 0 ) {				// AcceptRole
			bQuit = true;
			dlgSave();
		} else {
			dlgClose();
		}
	} else {
		dlgClose();
	}
}

void Ldoss::dlgClose()						// close settings dialog
{
	wSetDlg.hide();
	exit(0);
}


// ********************************************************************************************************************
// **  about/help/error widget handling  **
// ****************************************
void Ldoss::ahwAbout()						// about clicked
{
	ahwCreate( 1 );
}

void Ldoss::ahwHelp()						// help clicked
{
	ahwCreate( 2 );
}

void Ldoss::ahwCreate( int iD )				// create about/help/error dialog widget
{
//  cout << "ahwCreate reached " << QString::number( iD ).toStdString() << endl;                                               // *****  debug  *****
	if( bObjAhw == false ) {
		ahw = new aboutHelp();
		connect( this, SIGNAL( sigDlgAbout() ), ahw, SLOT( showAbout() ) );
		connect( this, SIGNAL( sigDlgHelp() ), ahw, SLOT( showHelp() ) );
//		connect( this, SIGNAL( sigDlgErr() ), ahw, SLOT( showErr() ) );
		connect( ahw, SIGNAL( sigAhwClosed() ), this, SLOT( ahwClosed() ) );
		bObjAhw = true;
		if( iD == 1 ) {
			emit sigDlgAbout();
		} else if( iD == 2 ) {
			emit sigDlgHelp();
		}
	}
}

void Ldoss::ahwClosed()						// ahw widget was closed
{
	ahw->deleteLater();
	bObjAhw = false;
}


#include "ldoss.moc"
