/***************************************************************************
   ldossc.cpp - main program, console (none GUI) mode
                           -------------------
   copyright : (C) 2010 by Helge Kortendieck  alan@kasmithee.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "ldossc.h"

Ldossc::Ldossc( QObject *parent) : QObject(parent)
{
	setRead();
	if( sProgs != "" ) {					// any programs to launch
		timerStart();
	} else {
		cout << "ldoss: Ooops, no programs to launch defined.\n"
				"ldoss: Start program without arguments in a graphical environment.\n"
				"ldoss: Aborting...\n" << endl;
		exitDo();
	}
}

Ldossc::~Ldossc()
{
}

void Ldossc::setRead()
{
	QSettings settings( "ldoss", "ldoss" );

	settings.beginGroup( "main" );
		sProgs = settings.value( "progs", "" ).toString();	// programs to launch, text edit content
		iDelay = settings.value( "delay", "500" ).toInt();	// delay to begin launch in milli seconds
	settings.endGroup();
}

void Ldossc::exitDo()						// finally exit
{
	QCoreApplication::exit();
}


void Ldossc::timerStart()					// start delay timer to start programs later
{
	QTimer::singleShot( iDelay, this, SLOT( launchProgs() ) );
}

void Ldossc::launchProgs()					// launch programs detached
{
	sCmds = sProgs;
	while( sCmds != "" ) {
		iD = sCmds.indexOf( '\n' );
		if( iD == 0 or iD == -1 ) {
			break;
		}
		sCurCmdLine = sCmds.left( iD );
		sCmds.remove( 0, iD + 1 );					// delete current command from list (qstring), +1 pos=already+1,  to incl \n
		slD = sCurCmdLine.simplified().split( " " );
		if( slD.count() > 0 ) {						// should always be true
			sProg = slD.at(0);
			slD.pop_front();						// slD holds now the comman line options
			bStart = QProcess::startDetached( sProg, slD );
			if( bStart == false ) {
				cout << "ldoss(c): failed to start: " << sCurCmdLine.toStdString() << endl;
			}
		}
	}
	exitDo();
}


#include "ldossc.moc"
